@@ -164,11 +164,21 @@ def convert(context, args, dialect=None):
 
 def run_command(command, context):
     command_line = command.get_command_line()
+    
+    # in some cases, such as Subversion's version of the
+    # generic "commit", which is supposed to commit locally,
+    # the command itself runs no vcs commands.
+    if not command_line:
+        return command.get_output()
+        
     log.debug("Running: %s", (command_line,))
     log.debug("Working dir: %s", context.working_dir)
     
     returncode, stdout = run_in_directory(context.working_dir, command_line)
     
+    if returncode == 0 and hasattr(command, "command_successful"):
+        command.command_successful()
+    
     output = command.process_output(returncode, stdout)
     log.debug("Command output: %s", output)
     return output
